aboutsummaryrefslogtreecommitdiffstats
path: root/cmd/puppeth/wizard_network.go
diff options
context:
space:
mode:
authorNilesh Trivedi <nilesh@hypertrack.io>2018-08-20 21:54:38 +0800
committerPéter Szilágyi <peterke@gmail.com>2018-08-20 21:54:38 +0800
commit7d38d53ae449c6ec06f7b0579f1a189b02222a60 (patch)
treea0ef49b4d1dc592dea74ef0cb0ec4b3fc6b86f53 /cmd/puppeth/wizard_network.go
parent1de9ada4016d7028d1d1529bc7d0676c98ddb5e4 (diff)
downloaddexon-7d38d53ae449c6ec06f7b0579f1a189b02222a60.tar
dexon-7d38d53ae449c6ec06f7b0579f1a189b02222a60.tar.gz
dexon-7d38d53ae449c6ec06f7b0579f1a189b02222a60.tar.bz2
dexon-7d38d53ae449c6ec06f7b0579f1a189b02222a60.tar.lz
dexon-7d38d53ae449c6ec06f7b0579f1a189b02222a60.tar.xz
dexon-7d38d53ae449c6ec06f7b0579f1a189b02222a60.tar.zst
dexon-7d38d53ae449c6ec06f7b0579f1a189b02222a60.zip
cmd/puppeth: accept ssh identity in the server string (#17407)
* cmd/puppeth: Accept identityfile in the server string with fallback to id_rsa * cmd/puppeth: code polishes + fix heath check double ports
Diffstat (limited to 'cmd/puppeth/wizard_network.go')
-rw-r--r--cmd/puppeth/wizard_network.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/cmd/puppeth/wizard_network.go b/cmd/puppeth/wizard_network.go
index d780c550b..c0ddcc2a3 100644
--- a/cmd/puppeth/wizard_network.go
+++ b/cmd/puppeth/wizard_network.go
@@ -62,14 +62,14 @@ func (w *wizard) manageServers() {
}
}
// makeServer reads a single line from stdin and interprets it as a hostname to
// connect to. It tries to establish a new SSH session and also executing some
// baseline validations.
//
// If connection succeeds, the server is added to the wizards configs!
func (w *wizard) makeServer() string {
fmt.Println()
- fmt.Println("Please enter remote server's address:")
+ fmt.Println("What is the remote server's address ([username[:identity]@]hostname[:port])?")
// Read and dial the server to ensure docker is present
input := w.readString()
@@ -62,14 +62,14 @@ func (w *wizard) manageServers() {
}
}
-// makeServer reads a single line from stdin and interprets it as a hostname to
-// connect to. It tries to establish a new SSH session and also executing some
-// baseline validations.
+// makeServer reads a single line from stdin and interprets it as
+// username:identity@hostname to connect to. It tries to establish a
+// new SSH session and also executing some baseline validations.
//
// If connection succeeds, the server is added to the wizards configs!